# ResponseFormatDto


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 

## Example

```python
from openapi_client.models.response_format_dto import ResponseFormatDto

# TODO update the JSON string below
json = "{}"
# create an instance of ResponseFormatDto from a JSON string
response_format_dto_instance = ResponseFormatDto.from_json(json)
# print the JSON string representation of the object
print ResponseFormatDto.to_json()

# convert the object into a dict
response_format_dto_dict = response_format_dto_instance.to_dict()
# create an instance of ResponseFormatDto from a dict
response_format_dto_form_dict = response_format_dto.from_dict(response_format_dto_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


